@@ -53,7 +53,7 @@ class Collection(object):
 
         if not name or ".." in name:
             raise InvalidName("collection names cannot be empty")
-        if "$" in name and name not in ["$cmd"]:
+        if "$" in name and not (name in ["$cmd"] or name.startswith("$cmd")):
             raise InvalidName("collection names must not contain '$'")
         if name[0] == "." or name[-1] == ".":
             raise InvalidName("collecion names must not start or end with '.'")
