@@ -36,13 +36,24 @@ class TestConnection(unittest.TestCase):
     def test_types(self):
         self.assertRaises(TypeError, Connection, 1)
         self.assertRaises(TypeError, Connection, 1.14)
-        self.assertRaises(TypeError, Connection, None)
         self.assertRaises(TypeError, Connection, [])
         self.assertRaises(TypeError, Connection, "localhost", "27017")
         self.assertRaises(TypeError, Connection, "localhost", 1.14)
-        self.assertRaises(TypeError, Connection, "localhost", None)
         self.assertRaises(TypeError, Connection, "localhost", [])
 
+    def test_constants(self):
+        Connection.HOST = self.host
+        Connection.PORT = self.port
+        self.assert_(Connection())
+
+        Connection.HOST = "somedomainthatdoesntexist.org"
+        Connection.PORT = 123456789
+        self.assertRaises(ConnectionFailure, Connection)
+
+        Connection.HOST = self.host
+        Connection.PORT = self.port
+        self.assert_(Connection())
+
     def test_connect(self):
         self.assertRaises(ConnectionFailure, Connection, "somedomainthatdoesntexist.org")
         self.assertRaises(ConnectionFailure, Connection, self.host, 123456789)
