@@ -40,8 +40,6 @@ class TestPooling(unittest.TestCase):
         self.no_auto_pooled_db = no_auto_pooled_connection["pymongo_test"]
 
     def test_exceptions(self):
-        self.assertRaises(TypeError, Connection, self.host, self.port,
-                          pool_size=None)
         self.assertRaises(TypeError, Connection, self.host, self.port,
                           pool_size="one")
         self.assertRaises(TypeError, Connection, self.host, self.port,
@@ -51,6 +49,14 @@ class TestPooling(unittest.TestCase):
         self.assertRaises(ValueError, Connection, self.host, self.port,
                           pool_size=0)
 
+    def test_constants(self):
+        Connection.POOL_SIZE = -1
+        self.assertRaises(ValueError, Connection, self.host, self.port)
+
+        Connection.POOL_SIZE = 1
+        self.assert_(Connection(self.host, self.port))
+
+
     # NOTE this test is non-deterministic
     def test_end_request(self):
         count = 0
